durationtools.duration_pair_to_prolation_string
===============================================

.. autofunction:: abjad.tools.durationtools.duration_pair_to_prolation_string.duration_pair_to_prolation_string
